The Foundry | Smart software for creative people
Description: The Foundry is a global developer of computer graphics, visual effects (VFX) and 3D design software for the design, visualization and entertainment industries.

- # Smart software for creative people

# NUKE, NUKEX & NUKE STUDIO, out now

# FLIX foodimals

We hosted the enigmatic Kris Pearn on our booth at SIGGRAPH 2014. Watch how he captivated our audience & see the winning foodimals drawn live.

# Cellular Forms

Andy Lomas tells us how he turned his passion for art and science into an award winning project.

# Join in the festive fun with our competition

It's that time of year again, time for our MODO holiday competition! Whether you’re one of our seasoned MODOnauts or complete beginner, there are categories and prizes for you. To enter, create a holiday themed image for our holiday e-card, which we will also use across our website too.

The categories and prizes are: I love MODO - where you could win a Creation COLLECTIVE and more, and Rising Stars - for those looking to learn and you could win a MODO 801 and more. Plus we’ll be rewarding a random entree with any MODO training course of your choice.

With so many great prizes on offer what are you waiting for? You have until Thursday 18th December to enter. Good Luck!

# Join us in Seoul and Shenzhen this fall

# Architectural Design

Don't miss our fourth Session, see Cityscape's Joel Azopardi & Damian Fennell show how they used MODO & NUKE for a regeneration project.

# COLORWAY now for CINEMA 4D

Introducing the free COLORWAY kit for C4D, which lets users import and export their files from C4D to the app.